Class: Aws::Organizations::Types::CreateAccountResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::CreateAccountResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_account_status ⇒ Types::CreateAccountStatus
A structure that contains details about the request to create an account.
Instance Attribute Details
#create_account_status ⇒ Types::CreateAccountStatus
A structure that contains details about the request to create an account. This response structure might not be fully populated when you first receive it because account creation is an asynchronous process. You can pass the returned CreateAccountStatus ID as a parameter to DescribeCreateAccountStatus to get status about the progress of the request at later times. You can also check the CloudTrail log for the CreateAccountResult event. For more information, see [Logging and monitoring in Organizations] in the *Organizations User Guide*.
[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_security_incident-response.html
832 833 834 835 836 |
# File 'lib/aws-sdk-organizations/types.rb', line 832 class CreateAccountResponse < Struct.new( :create_account_status) SENSITIVE = [] include Aws::Structure end |