Class: Aws::Organizations::Types::DeleteOrganizationalUnitRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::DeleteOrganizationalUnitRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#organizational_unit_id ⇒ String
ID for the organizational unit that you want to delete.
Instance Attribute Details
#organizational_unit_id ⇒ String
ID for the organizational unit that you want to delete. You can get the ID from the ListOrganizationalUnitsForParent operation.
The regex pattern for an organizational unit ID string requires "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
1515 1516 1517 1518 1519 |
# File 'lib/aws-sdk-organizations/types.rb', line 1515 class DeleteOrganizationalUnitRequest < Struct.new( :organizational_unit_id) SENSITIVE = [] include Aws::Structure end |