Class: Aws::Organizations::Types::DescribeAccountResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::Account

A structure that contains information about the requested account.

The Status parameter in the API response will be retired on September 9, 2026. Although both the account State and account Status parameters are currently available in the Organizations APIs (DescribeAccount, ListAccounts, ListAccountsForParent), we recommend that you update your scripts or other code to use the State parameter instead of Status before September 9, 2026.

Returns:



1601
1602
1603
1604
1605
# File 'lib/aws-sdk-organizations/types.rb', line 1601

class DescribeAccountResponse < Struct.new(
  :account)
  SENSITIVE = []
  include Aws::Structure
end