Class: Aws::Organizations::Types::DescribeCreateAccountStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_account_request_idString

Specifies the Id value that uniquely identifies the CreateAccount request. You can get the value from the CreateAccountStatus.Id response in an earlier CreateAccount request, or from the ListCreateAccountStatus operation.

The regex pattern for a create account request ID string requires "car-" followed by from 8 to 32 lowercase letters or digits.

Returns:

  • (String)


1624
1625
1626
1627
1628
# File 'lib/aws-sdk-organizations/types.rb', line 1624

class DescribeCreateAccountStatusRequest < Struct.new(
  :create_account_request_id)
  SENSITIVE = []
  include Aws::Structure
end