Class: Aws::Organizations::Types::DescribeEffectivePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_typeString

Returns:

  • (String)


1692
1693
1694
1695
1696
1697
# File 'lib/aws-sdk-organizations/types.rb', line 1692

class DescribeEffectivePolicyRequest < Struct.new(
  :policy_type,
  :target_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_idString

When you're signed in as the management account, specify the ID of the account that you want details about. Specifying an organization root or organizational unit (OU) as the target is not supported.

Returns:

  • (String)


1692
1693
1694
1695
1696
1697
# File 'lib/aws-sdk-organizations/types.rb', line 1692

class DescribeEffectivePolicyRequest < Struct.new(
  :policy_type,
  :target_id)
  SENSITIVE = []
  include Aws::Structure
end