Class: Aws::Organizations::Types::DescribeHandshakeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::DescribeHandshakeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#handshake_id ⇒ String
ID for the handshake that you want information about.
Instance Attribute Details
#handshake_id ⇒ String
ID for the handshake that you want information about.
The [regex pattern] for handshake ID string requires “h-” followed by from 8 to 32 lowercase letters or digits.
1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-organizations/types.rb', line 1707 class DescribeHandshakeRequest < Struct.new( :handshake_id) SENSITIVE = [] include Aws::Structure end |