Class: Aws::Organizations::Types::DescribeOrganizationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::DescribeOrganizationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#organization ⇒ Types::Organization
A structure that contains information about the organization.
Instance Attribute Details
#organization ⇒ Types::Organization
A structure that contains information about the organization.
The ‘AvailablePolicyTypes` part of the response is deprecated, and you shouldn’t use it in your apps. It doesn’t include any policy type supported by Organizations other than SCPs. In the China (Ningxia) Region, no policy type is included. To determine which policy types are enabled in your organization, use the ‘ ListRoots ` operation.
1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-organizations/types.rb', line 1743 class DescribeOrganizationResponse < Struct.new( :organization) SENSITIVE = [] include Aws::Structure end |