Class: Aws::Organizations::Types::DetachPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_idString

ID for the policy you want to detach. You can get the ID from the ListPolicies or ListPoliciesForTarget operations.

The [regex pattern] for a policy ID string requires “p-” followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-organizations/types.rb', line 1906

class DetachPolicyRequest < Struct.new(
  :policy_id,
  :target_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_idString

ID for the root, OU, or account that you want to detach the policy from. You can get the ID from the ListRoots, ListOrganizationalUnitsForParent, or ListAccounts operations.

The [regex pattern] for a target ID string requires one of the following:

  • Root - A string that begins with “r-” followed by from 4 to 32 lowercase letters or digits.

  • Account - A string that consists of exactly 12 digits.

  • **Organizational unit (OU)** - A string that begins with “ou-” followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is in). This string is followed by a second “-” dash and from 8 to 32 additional lowercase letters or digits.

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-organizations/types.rb', line 1906

class DetachPolicyRequest < Struct.new(
  :policy_id,
  :target_id)
  SENSITIVE = []
  include Aws::Structure
end