Class: Aws::Organizations::Types::DisablePolicyTypeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_typeString

The policy type that you want to disable in this root. You can specify one of the following values:

  • SERVICE_CONTROL_POLICY][1
  • RESOURCE_CONTROL_POLICY][2
  • DECLARATIVE_POLICY_EC2][3
  • BACKUP_POLICY][4
  • TAG_POLICY][5
  • CHATBOT_POLICY][6
  • AISERVICES_OPT_OUT_POLICY][7
  • SECURITYHUB_POLICY][8
  • UPGRADE_ROLLOUT_POLICY][9
  • INSPECTOR_POLICY][10
  • BEDROCK_POLICY][11
  • S3_POLICY][12
  • NETWORK_SECURITY_DIRECTOR_POLICY][13

[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_scp.html [2]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_rcps.html [3]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_declarative.html [4]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_backup.html [5]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_tag-policies.html [6]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_chatbot.html [7]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_ai-opt-out.html [8]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_security_hub.html [9]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_upgrade_rollout.html [10]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_inspector.html [11]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_bedrock.html [12]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_s3.html [13]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_network_security_director.html

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-organizations/types.rb', line 1984

class DisablePolicyTypeRequest < Struct.new(
  :root_id,
  :policy_type)
  SENSITIVE = []
  include Aws::Structure
end

#root_idString

ID for the root in which you want to disable a policy type. You can get the ID from the ListRoots operation.

The [regex pattern] for a root ID string requires “r-” followed by from 4 to 32 lowercase letters or digits.

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
# File 'lib/aws-sdk-organizations/types.rb', line 1984

class DisablePolicyTypeRequest < Struct.new(
  :root_id,
  :policy_type)
  SENSITIVE = []
  include Aws::Structure
end