Class: Aws::Organizations::Types::EffectivePolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::EffectivePolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Contains rules to be applied to the affected accounts. The effective policy is the aggregation of any policies the account inherits, plus any policy directly attached to the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_timestamp ⇒ Time
The time of the last update to this policy.
-
#policy_content ⇒ String
The text content of the policy.
-
#policy_type ⇒ String
The policy type.
-
#target_id ⇒ String
The account ID of the policy target.
Instance Attribute Details
#last_updated_timestamp ⇒ Time
The time of the last update to this policy.
2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'lib/aws-sdk-organizations/types.rb', line 2113 class EffectivePolicy < Struct.new( :policy_content, :last_updated_timestamp, :target_id, :policy_type) SENSITIVE = [] include Aws::Structure end |
#policy_content ⇒ String
The text content of the policy.
2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'lib/aws-sdk-organizations/types.rb', line 2113 class EffectivePolicy < Struct.new( :policy_content, :last_updated_timestamp, :target_id, :policy_type) SENSITIVE = [] include Aws::Structure end |
#policy_type ⇒ String
The policy type.
2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'lib/aws-sdk-organizations/types.rb', line 2113 class EffectivePolicy < Struct.new( :policy_content, :last_updated_timestamp, :target_id, :policy_type) SENSITIVE = [] include Aws::Structure end |
#target_id ⇒ String
The account ID of the policy target.
2113 2114 2115 2116 2117 2118 2119 2120 |
# File 'lib/aws-sdk-organizations/types.rb', line 2113 class EffectivePolicy < Struct.new( :policy_content, :last_updated_timestamp, :target_id, :policy_type) SENSITIVE = [] include Aws::Structure end |