Class: Aws::Organizations::Types::EffectivePolicyValidationError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::EffectivePolicyValidationError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Contains details about the validation errors that occurred when generating or enforcing an effective policy, such as which policies contributed to the error and location of the error.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contributing_policies ⇒ Array<String>
The individual policies [inherited][1] and [attached][2] to the account which contributed to the validation error.
-
#error_code ⇒ String
The error code for the validation error.
-
#error_message ⇒ String
The error message for the validation error.
-
#path_to_error ⇒ String
The path within the effective policy where the validation error occurred.
Instance Attribute Details
#contributing_policies ⇒ Array<String>
2173 2174 2175 2176 2177 2178 2179 2180 |
# File 'lib/aws-sdk-organizations/types.rb', line 2173 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |
#error_code ⇒ String
The error code for the validation error. For example,
ELEMENTS_TOO_MANY.
2173 2174 2175 2176 2177 2178 2179 2180 |
# File 'lib/aws-sdk-organizations/types.rb', line 2173 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message for the validation error.
2173 2174 2175 2176 2177 2178 2179 2180 |
# File 'lib/aws-sdk-organizations/types.rb', line 2173 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |
#path_to_error ⇒ String
The path within the effective policy where the validation error occurred.
2173 2174 2175 2176 2177 2178 2179 2180 |
# File 'lib/aws-sdk-organizations/types.rb', line 2173 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |