Class: Aws::Organizations::Types::HandshakeConstraintViolationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::HandshakeConstraintViolationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
The requested operation would violate the constraint identified in the reason code.
-
ACCOUNT_NUMBER_LIMIT_EXCEEDED: You attempted to exceed the limit on the number of accounts in an organization. Note that deleted and closed accounts still count toward your limit.
If you get this exception immediately after creating the organization, wait one hour and try again. If after an hour it continues to fail with this error, contact Amazon Web Services Support.
-
ALREADY_IN_AN_ORGANIZATION: The handshake request is invalid because the invited account is already a member of an organization.
-
HANDSHAKE_RATE_LIMIT_EXCEEDED: You attempted to exceed the number of handshakes that you can send in one day.
-
INVITE_DISABLED_DURING_ENABLE_ALL_FEATURES: You can't issue new invitations to join an organization while it's in the process of enabling all features. You can resume inviting accounts after you finalize the process when all accounts have agreed to the change.
-
LEGACY_PERMISSIONS_STILL_IN_USE: Your organization must migrate to use the new IAM fine-grained actions for billing, cost management, and accounts.
-
ORGANIZATION_ALREADY_HAS_ALL_FEATURES: The handshake request is invalid because the organization has already enabled all features.
-
ORGANIZATION_FROM_DIFFERENT_SELLER_OF_RECORD: You can only join an organization that operates in the same Amazon Web Services partition as your account.
-
ORGANIZATION_IS_ALREADY_PENDING_ALL_FEATURES_MIGRATION: The handshake request is invalid because the organization has already started the process to enable all features.
-
ORGANIZATION_MEMBERSHIP_CHANGE_RATE_LIMIT_EXCEEDED: You attempted to change the membership of an account too quickly after its previous change.
-
PAST_DUE_INVOICE: Your organization has an invoice that is past due.
-
PAYMENT_INSTRUMENT_REQUIRED: You can't complete the operation with an account that doesn't have a payment instrument, such as a credit card, associated with it.
-
RESPONSIBILITY_TRANSFER_ALREADY_EXISTS: You cannot perform this operation with the current transfer.
-
SOURCE_AND_TARGET_CANNOT_MATCH: An account can't accept a transfer invitation if it is both the sender and recipient of the invitation.
-
TARGET_ACCOUNT_VALIDATION_FAILURE: Billing transfer is not available for your account. Contact your billing administrator or Amazon Web Services Support for assistance.
-
UNUSED_PREPAYMENT_BALANCE: Your organization has an outstanding pre-payment balance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
2535 2536 2537 2538 2539 2540 |
# File 'lib/aws-sdk-organizations/types.rb', line 2535 class HandshakeConstraintViolationException < Struct.new( :message, :reason) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
2535 2536 2537 2538 2539 2540 |
# File 'lib/aws-sdk-organizations/types.rb', line 2535 class HandshakeConstraintViolationException < Struct.new( :message, :reason) SENSITIVE = [] include Aws::Structure end |