Class: Aws::Organizations::Types::HandshakeParty

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Contains details for a participant in a handshake.

Constant Summary collapse

SENSITIVE =
[:id]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

ID for the participant: Acccount ID, organization ID, or email address.

The regex pattern for handshake ID string requires "h-" followed by from 8 to 32 lowercase letters or digits.

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
# File 'lib/aws-sdk-organizations/types.rb', line 2614

class HandshakeParty < Struct.new(
  :id,
  :type)
  SENSITIVE = [:id]
  include Aws::Structure
end

#typeString

The type of ID for the participant.

ORGANIZATION is valid only in the response context (identifying the inviting organization). Valid input values for the Target parameter are ACCOUNT and EMAIL only.

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
# File 'lib/aws-sdk-organizations/types.rb', line 2614

class HandshakeParty < Struct.new(
  :id,
  :type)
  SENSITIVE = [:id]
  include Aws::Structure
end