Class: Aws::Organizations::Types::InviteOrganizationToTransferResponsibilityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::InviteOrganizationToTransferResponsibilityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:notes, :source_name]
Instance Attribute Summary collapse
-
#notes ⇒ String
Additional information that you want to include in the invitation.
-
#source_name ⇒ String
Name you want to assign to the transfer.
-
#start_timestamp ⇒ Time
Timestamp when the recipient will begin managing the specified responsibilities.
-
#tags ⇒ Array<Types::Tag>
A list of tags that you want to attach to the transfer.
-
#target ⇒ Types::HandshakeParty
A
HandshakePartyobject. -
#type ⇒ String
The type of responsibility you want to designate to your organization.
Instance Attribute Details
#notes ⇒ String
Additional information that you want to include in the invitation.
2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-organizations/types.rb', line 2926 class InviteOrganizationToTransferResponsibilityRequest < Struct.new( :type, :target, :notes, :start_timestamp, :source_name, :tags) SENSITIVE = [:notes, :source_name] include Aws::Structure end |
#source_name ⇒ String
Name you want to assign to the transfer.
2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-organizations/types.rb', line 2926 class InviteOrganizationToTransferResponsibilityRequest < Struct.new( :type, :target, :notes, :start_timestamp, :source_name, :tags) SENSITIVE = [:notes, :source_name] include Aws::Structure end |
#start_timestamp ⇒ Time
Timestamp when the recipient will begin managing the specified responsibilities.
2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-organizations/types.rb', line 2926 class InviteOrganizationToTransferResponsibilityRequest < Struct.new( :type, :target, :notes, :start_timestamp, :source_name, :tags) SENSITIVE = [:notes, :source_name] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags that you want to attach to the transfer. For each tag in the list, you must specify both a tag key and a value. You can set the value to an empty string, but you can’t set it to null. For more information about tagging, see [Tagging Organizations resources] in the Organizations User Guide.
Any tags in the request are checked for compliance with any applicable tag policies when the request is made. The request is rejected if the tags in the request don’t match the requirements of the policy at that time. Tag policy compliance is not checked again when the invitation is accepted and the tags are actually attached to the transfer. That means that if the tag policy changes between the invitation and the acceptance, then that tags could potentially be non-compliant.
<note markdown=“1”> If any one of the tags is not valid or if you exceed the allowed number of tags for a transfer, then the entire request fails and invitations are not sent.
</note>
[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html
2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-organizations/types.rb', line 2926 class InviteOrganizationToTransferResponsibilityRequest < Struct.new( :type, :target, :notes, :start_timestamp, :source_name, :tags) SENSITIVE = [:notes, :source_name] include Aws::Structure end |
#target ⇒ Types::HandshakeParty
A HandshakeParty object. Contains details for the account you want to invite. Currently, only ACCOUNT and EMAIL are supported.
2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-organizations/types.rb', line 2926 class InviteOrganizationToTransferResponsibilityRequest < Struct.new( :type, :target, :notes, :start_timestamp, :source_name, :tags) SENSITIVE = [:notes, :source_name] include Aws::Structure end |
#type ⇒ String
The type of responsibility you want to designate to your organization. Currently, only BILLING is supported.
2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 |
# File 'lib/aws-sdk-organizations/types.rb', line 2926 class InviteOrganizationToTransferResponsibilityRequest < Struct.new( :type, :target, :notes, :start_timestamp, :source_name, :tags) SENSITIVE = [:notes, :source_name] include Aws::Structure end |