Class: Aws::Organizations::Types::InviteOrganizationToTransferResponsibilityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::InviteOrganizationToTransferResponsibilityResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#handshake ⇒ Types::Handshake
Contains details for a handshake.
Instance Attribute Details
#handshake ⇒ Types::Handshake
Contains details for a handshake. A handshake is the secure exchange of information between two Amazon Web Services accounts: a sender and a recipient.
Note: Handshakes that are CANCELED, ACCEPTED, DECLINED, or EXPIRED show up in lists for only 30 days after entering that state After that they are deleted.
2949 2950 2951 2952 2953 |
# File 'lib/aws-sdk-organizations/types.rb', line 2949 class InviteOrganizationToTransferResponsibilityResponse < Struct.new( :handshake) SENSITIVE = [] include Aws::Structure end |