Class: Aws::Organizations::Types::MalformedPolicyDocumentException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

The provided policy document doesn't meet the requirements of the specified policy type. For example, the syntax might be incorrect. For details about service control policy syntax, see SCP syntax in the Organizations User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


4387
4388
4389
4390
4391
# File 'lib/aws-sdk-organizations/types.rb', line 4387

class MalformedPolicyDocumentException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end