Class: Aws::Organizations::Types::Policy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Contains rules to be applied to the affected accounts. Policies can be attached directly to accounts, or to roots and OUs to affect all accounts in those hierarchies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The text content of the policy.

Returns:

  • (String)


4729
4730
4731
4732
4733
4734
# File 'lib/aws-sdk-organizations/types.rb', line 4729

class Policy < Struct.new(
  :policy_summary,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#policy_summaryTypes::PolicySummary

A structure that contains additional details about the policy.



4729
4730
4731
4732
4733
4734
# File 'lib/aws-sdk-organizations/types.rb', line 4729

class Policy < Struct.new(
  :policy_summary,
  :content)
  SENSITIVE = []
  include Aws::Structure
end