Class: Aws::Organizations::Types::PolicySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Contains information about a policy, but does not include the content. To see the content of a policy, see DescribePolicy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the policy.

For more information about ARNs in Organizations, see [ARN Formats Supported by Organizations] in the *Amazon Web Services Service Authorization Reference*.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsorganizations.html#awsorganizations-resources-for-iam-policies

Returns:

  • (String)


4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
# File 'lib/aws-sdk-organizations/types.rb', line 4815

class PolicySummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :type,
  :aws_managed)
  SENSITIVE = []
  include Aws::Structure
end

#aws_managedBoolean

A boolean value that indicates whether the specified policy is an Amazon Web Services managed policy. If true, then you can attach the policy to roots, OUs, or accounts, but you cannot edit it.

Returns:

  • (Boolean)


4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
# File 'lib/aws-sdk-organizations/types.rb', line 4815

class PolicySummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :type,
  :aws_managed)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the policy.

Returns:

  • (String)


4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
# File 'lib/aws-sdk-organizations/types.rb', line 4815

class PolicySummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :type,
  :aws_managed)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier (ID) of the policy.

The [regex pattern] for a policy ID string requires “p-” followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
# File 'lib/aws-sdk-organizations/types.rb', line 4815

class PolicySummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :type,
  :aws_managed)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The friendly name of the policy.

The [regex pattern] that is used to validate this parameter is a string of any of the characters in the ASCII character range.

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
# File 'lib/aws-sdk-organizations/types.rb', line 4815

class PolicySummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :type,
  :aws_managed)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of policy.

Returns:

  • (String)


4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
# File 'lib/aws-sdk-organizations/types.rb', line 4815

class PolicySummary < Struct.new(
  :id,
  :arn,
  :name,
  :description,
  :type,
  :aws_managed)
  SENSITIVE = []
  include Aws::Structure
end