Class: Aws::Organizations::Types::PolicyTypeNotAvailableForOrganizationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::PolicyTypeNotAvailableForOrganizationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
You can't use the specified policy type with the feature set currently enabled for this organization. For example, you can enable SCPs only after you enable all features in the organization. For more information, see Managing Organizations policiesin the Organizations User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
4947 4948 4949 4950 4951 |
# File 'lib/aws-sdk-organizations/types.rb', line 4947 class PolicyTypeNotAvailableForOrganizationException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |