Class: Aws::Organizations::Types::ResponsibilityTransfer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Contains details for a transfer. A transfer is the arrangement between two management accounts where one account designates the other with specified responsibilities for their organization.

Constant Summary collapse

SENSITIVE =
[:name]

Instance Attribute Summary collapse

Instance Attribute Details

#active_handshake_idString

ID for the handshake of the transfer.

Returns:

  • (String)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#arnString

Amazon Resource Name (ARN) for the transfer.

Returns:

  • (String)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#end_timestampTime

Timestamp when the transfer ends.

Returns:

  • (Time)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#idString

ID for the transfer.

Returns:

  • (String)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#nameString

Name assigned to the transfer.

Returns:

  • (String)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#sourceTypes::TransferParticipant

Account that allows another account external to its organization to manage the specified responsibilities for the organization.



5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#start_timestampTime

Timestamp when the transfer starts.

Returns:

  • (Time)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#statusString

Status for the transfer.

Returns:

  • (String)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#targetTypes::TransferParticipant

Account that manages the specified responsibilities for another organization.



5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#typeString

The type of transfer. Currently, only BILLING is supported.

Returns:

  • (String)


5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
5203
5204
# File 'lib/aws-sdk-organizations/types.rb', line 5191

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end