Class: Aws::Organizations::Types::CreatePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The policy text content to add to the new policy. The text that you supply must adhere to the rules of the policy type you specify in the ‘Type` parameter.

The maximum size of a policy document depends on the policy’s type. For more information, see [Maximum and minimum values] in the *Organizations User Guide*.

[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_limits.html#min-max-values

Returns:

  • (String)


1339
1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/aws-sdk-organizations/types.rb', line 1339

class CreatePolicyRequest < Struct.new(
  :content,
  :description,
  :name,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional description to assign to the policy.

Returns:

  • (String)


1339
1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/aws-sdk-organizations/types.rb', line 1339

class CreatePolicyRequest < Struct.new(
  :content,
  :description,
  :name,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The friendly name to assign to the policy.

The [regex pattern] that is used to validate this parameter is a string of any of the characters in the ASCII character range.

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


1339
1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/aws-sdk-organizations/types.rb', line 1339

class CreatePolicyRequest < Struct.new(
  :content,
  :description,
  :name,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags that you want to attach to the newly created policy. For each tag in the list, you must specify both a tag key and a value. You can set the value to an empty string, but you can’t set it to ‘null`. For more information about tagging, see [Tagging Organizations resources] in the Organizations User Guide.

<note markdown=“1”> If any one of the tags is not valid or if you exceed the allowed number of tags for a policy, then the entire request fails and the policy is not created.

</note>

[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_tagging.html

Returns:



1339
1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/aws-sdk-organizations/types.rb', line 1339

class CreatePolicyRequest < Struct.new(
  :content,
  :description,
  :name,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of policy to create. You can specify one of the following values:

  • SERVICE_CONTROL_POLICY][1
  • RESOURCE_CONTROL_POLICY][2
  • DECLARATIVE_POLICY_EC2][3
  • BACKUP_POLICY][4
  • TAG_POLICY][5
  • CHATBOT_POLICY][6
  • AISERVICES_OPT_OUT_POLICY][7
  • SECURITYHUB_POLICY][8
  • UPGRADE_ROLLOUT_POLICY][9
  • INSPECTOR_POLICY][10
  • BEDROCK_POLICY][11
  • S3_POLICY][12
  • NETWORK_SECURITY_DIRECTOR_POLICY][13

[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_scp.html [2]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_rcps.html [3]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_declarative.html [4]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_backup.html [5]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_tag-policies.html [6]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_chatbot.html [7]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_ai-opt-out.html [8]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_security_hub.html [9]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_upgrade_rollout.html [10]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_inspector.html [11]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_bedrock.html [12]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_s3.html [13]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_network_security_director.html

Returns:

  • (String)


1339
1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/aws-sdk-organizations/types.rb', line 1339

class CreatePolicyRequest < Struct.new(
  :content,
  :description,
  :name,
  :type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end