Class: Aws::Organizations::Types::DescribeEffectivePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::DescribeEffectivePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_type ⇒ String
The type of policy that you want information about.
-
#target_id ⇒ String
When you're signed in as the management account, specify the ID of the account that you want details about.
Instance Attribute Details
#policy_type ⇒ String
The type of policy that you want information about. You can specify one of the following values:
1692 1693 1694 1695 1696 1697 |
# File 'lib/aws-sdk-organizations/types.rb', line 1692 class DescribeEffectivePolicyRequest < Struct.new( :policy_type, :target_id) SENSITIVE = [] include Aws::Structure end |
#target_id ⇒ String
When you're signed in as the management account, specify the ID of the account that you want details about. Specifying an organization root or organizational unit (OU) as the target is not supported.
1692 1693 1694 1695 1696 1697 |
# File 'lib/aws-sdk-organizations/types.rb', line 1692 class DescribeEffectivePolicyRequest < Struct.new( :policy_type, :target_id) SENSITIVE = [] include Aws::Structure end |