Class: Aws::Organizations::Types::EffectivePolicyValidationError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Contains details about the validation errors that occurred when generating or enforcing an [effective policy], such as which policies contributed to the error and location of the error.

[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_effective.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contributing_policiesArray<String>

Returns:

  • (Array<String>)


2156
2157
2158
2159
2160
2161
2162
2163
# File 'lib/aws-sdk-organizations/types.rb', line 2156

class EffectivePolicyValidationError < Struct.new(
  :error_code,
  :error_message,
  :path_to_error,
  :contributing_policies)
  SENSITIVE = []
  include Aws::Structure
end

#error_codeString

The error code for the validation error. For example, ELEMENTS_TOO_MANY.

Returns:

  • (String)


2156
2157
2158
2159
2160
2161
2162
2163
# File 'lib/aws-sdk-organizations/types.rb', line 2156

class EffectivePolicyValidationError < Struct.new(
  :error_code,
  :error_message,
  :path_to_error,
  :contributing_policies)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message for the validation error.

Returns:

  • (String)


2156
2157
2158
2159
2160
2161
2162
2163
# File 'lib/aws-sdk-organizations/types.rb', line 2156

class EffectivePolicyValidationError < Struct.new(
  :error_code,
  :error_message,
  :path_to_error,
  :contributing_policies)
  SENSITIVE = []
  include Aws::Structure
end

#path_to_errorString

The path within the effective policy where the validation error occurred.

Returns:

  • (String)


2156
2157
2158
2159
2160
2161
2162
2163
# File 'lib/aws-sdk-organizations/types.rb', line 2156

class EffectivePolicyValidationError < Struct.new(
  :error_code,
  :error_message,
  :path_to_error,
  :contributing_policies)
  SENSITIVE = []
  include Aws::Structure
end