Class: Aws::Organizations::Types::EffectivePolicyValidationError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::EffectivePolicyValidationError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Contains details about the validation errors that occurred when generating or enforcing an [effective policy], such as which policies contributed to the error and location of the error.
[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_effective.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contributing_policies ⇒ Array<String>
The individual policies [inherited] and [attached] to the account which contributed to the validation error.
-
#error_code ⇒ String
The error code for the validation error.
-
#error_message ⇒ String
The error message for the validation error.
-
#path_to_error ⇒ String
The path within the effective policy where the validation error occurred.
Instance Attribute Details
#contributing_policies ⇒ Array<String>
The individual policies [inherited] and [attached] to the account which contributed to the validation error.
[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_inheritance_mgmt.html [2]: docs.aws.amazon.com/organizations/latest/userguide/orgs_policies_attach.html
2156 2157 2158 2159 2160 2161 2162 2163 |
# File 'lib/aws-sdk-organizations/types.rb', line 2156 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |
#error_code ⇒ String
The error code for the validation error. For example, ELEMENTS_TOO_MANY.
2156 2157 2158 2159 2160 2161 2162 2163 |
# File 'lib/aws-sdk-organizations/types.rb', line 2156 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message for the validation error.
2156 2157 2158 2159 2160 2161 2162 2163 |
# File 'lib/aws-sdk-organizations/types.rb', line 2156 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |
#path_to_error ⇒ String
The path within the effective policy where the validation error occurred.
2156 2157 2158 2159 2160 2161 2162 2163 |
# File 'lib/aws-sdk-organizations/types.rb', line 2156 class EffectivePolicyValidationError < Struct.new( :error_code, :error_message, :path_to_error, :contributing_policies) SENSITIVE = [] include Aws::Structure end |