Class: Aws::Organizations::Types::Handshake

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Contains details for a handshake. A handshake is the secure exchange of information between two Amazon Web Services accounts: a sender and a recipient.

Note: Handshakes that are ‘CANCELED`, `ACCEPTED`, `DECLINED`, or `EXPIRED` show up in lists for only 30 days after entering that state After that they are deleted.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The type of handshake:

  • INVITE: Handshake sent to a standalone account requesting that it to join the sender’s organization.

  • ENABLE_ALL_FEATURES: Handshake sent to invited member accounts to enable all features for the organization.

  • APPROVE_ALL_FEATURES: Handshake sent to the management account when all invited member accounts have approved to enable all features.

  • TRANSFER_RESPONSIBILITY: Handshake sent to another organization’s management account requesting that it designate the sender with the specified responsibilities for recipient’s organization.

Returns:

  • (String)


2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

Amazon Resource Name (ARN) for the handshake.

For more information about ARNs in Organizations, see [ARN Formats Supported by Organizations] in the *Amazon Web Services Service Authorization Reference*.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsorganizations.html#awsorganizations-resources-for-iam-policies

Returns:

  • (String)


2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_timestampTime

Timestamp when the handshake expires.

Returns:

  • (Time)


2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#idString

ID for the handshake.

The [regex pattern] for handshake ID string requires “h-” followed by from 8 to 32 lowercase letters or digits.

[1]: wikipedia.org/wiki/regex

Returns:

  • (String)


2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#partiesArray<Types::HandshakeParty>

An array of ‘HandshakeParty` objects. Contains details for participant in a handshake.

Returns:



2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#requested_timestampTime

Timestamp when the handshake request was made.

Returns:

  • (Time)


2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<Types::HandshakeResource>

An array of ‘HandshakeResource` objects. When needed, contains additional details for a handshake. For example, the email address for the sender.

Returns:



2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Current state for the handshake.

  • REQUESTED: Handshake awaiting a response from the recipient.

  • OPEN: Handshake sent to multiple recipients and all recipients have responded. The sender can now complete the handshake action.

  • CANCELED: Handshake canceled by the sender.

  • ACCEPTED: Handshake accepted by the recipient.

  • DECLINED: Handshake declined by the recipient.

  • EXPIRED: Handshake has expired.

Returns:

  • (String)


2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/aws-sdk-organizations/types.rb', line 2416

class Handshake < Struct.new(
  :id,
  :arn,
  :parties,
  :state,
  :requested_timestamp,
  :expiration_timestamp,
  :action,
  :resources)
  SENSITIVE = []
  include Aws::Structure
end