Class: Aws::Organizations::Types::Policy
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::Policy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Contains rules to be applied to the affected accounts. Policies can be attached directly to accounts, or to roots and OUs to affect all accounts in those hierarchies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The text content of the policy.
-
#policy_summary ⇒ Types::PolicySummary
A structure that contains additional details about the policy.
Instance Attribute Details
#content ⇒ String
The text content of the policy.
4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-organizations/types.rb', line 4702 class Policy < Struct.new( :policy_summary, :content) SENSITIVE = [] include Aws::Structure end |
#policy_summary ⇒ Types::PolicySummary
A structure that contains additional details about the policy.
4702 4703 4704 4705 4706 4707 |
# File 'lib/aws-sdk-organizations/types.rb', line 4702 class Policy < Struct.new( :policy_summary, :content) SENSITIVE = [] include Aws::Structure end |