Class: Aws::Organizations::Types::PolicyTypeNotAvailableForOrganizationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::PolicyTypeNotAvailableForOrganizationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
You can’t use the specified policy type with the feature set currently enabled for this organization. For example, you can enable SCPs only after you enable all features in the organization. For more information, see [Managing Organizations policies]in the *Organizations User Guide*.
[1]: docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies.html#enable_policies_on_root
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
4907 4908 4909 4910 4911 |
# File 'lib/aws-sdk-organizations/types.rb', line 4907 class PolicyTypeNotAvailableForOrganizationException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |