Class: Aws::Organizations::Types::RemoveAccountFromOrganizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Organizations::Types::RemoveAccountFromOrganizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-organizations/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
ID for the member account that you want to remove from the organization.
Instance Attribute Details
#account_id ⇒ String
ID for the member account that you want to remove from the organization.
The regex pattern for an account ID string requires exactly 12 digits.
5058 5059 5060 5061 5062 |
# File 'lib/aws-sdk-organizations/types.rb', line 5058 class RemoveAccountFromOrganizationRequest < Struct.new( :account_id) SENSITIVE = [] include Aws::Structure end |