Class: Aws::Organizations::Types::ResponsibilityTransfer

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-organizations/types.rb

Overview

Contains details for a transfer. A transfer is the arrangement between two management accounts where one account designates the other with specified responsibilities for their organization.

Constant Summary collapse

SENSITIVE =
[:name]

Instance Attribute Summary collapse

Instance Attribute Details

#active_handshake_idString

ID for the handshake of the transfer.

Returns:

  • (String)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#arnString

Amazon Resource Name (ARN) for the transfer.

Returns:

  • (String)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#end_timestampTime

Timestamp when the transfer ends.

Returns:

  • (Time)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#idString

ID for the transfer.

Returns:

  • (String)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#nameString

Name assigned to the transfer.

Returns:

  • (String)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#sourceTypes::TransferParticipant

Account that allows another account external to its organization to manage the specified responsibilities for the organization.



5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#start_timestampTime

Timestamp when the transfer starts.

Returns:

  • (Time)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#statusString

Status for the transfer.

Returns:

  • (String)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#targetTypes::TransferParticipant

Account that manages the specified responsibilities for another organization.



5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end

#typeString

The type of transfer. Currently, only BILLING is supported.

Returns:

  • (String)


5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-organizations/types.rb', line 5172

class ResponsibilityTransfer < Struct.new(
  :arn,
  :name,
  :id,
  :type,
  :status,
  :source,
  :target,
  :start_timestamp,
  :end_timestamp,
  :active_handshake_id)
  SENSITIVE = [:name]
  include Aws::Structure
end